@@ -28,6 +28,7 @@ public:
     quint16 port = 3389;
 
     QList<User> users;
+    bool usePamAuthentication = false;
 
     std::filesystem::path tlsCertificate;
     std::filesystem::path tlsCertificateKey;
@@ -55,7 +56,8 @@ bool Server::start()
     }
 
     if (!listen(d->address, d->port)) {
-        qCCritical(KRDP) << "Unable to listen for connections on" << serverAddress() << serverPort();
+        // NOTE: We cannot use QTcpServer methods to get the server address and port because it won't initialize them if listen fails.
+        qCCritical(KRDP) << "Unable to listen for connections on" << d->address << d->port;
         return false;
     }
 
@@ -121,6 +123,16 @@ void KRdp::Server::addUser(const User &user)
     d->users.append(user);
 }
 
+bool Server::usePAMAuthentication() const
+{
+    return d->usePamAuthentication;
+}
+
+void Server::setUsePAMAuthentication(bool usePAM)
+{
+    d->usePamAuthentication = usePAM;
+}
+
 std::filesystem::path Server::tlsCertificate() const
 {
     return d->tlsCertificate;
