@@ -5,10 +5,12 @@
 #pragma once
 
 #include "krdpserversettings.h"
+#include "usersmodel.h"
 #include <KQuickManagedConfigModule>
 #include <qt6keychain/keychain.h>
 
 class KRDPServerConfigImpl;
+class QAbstractItemModel;
 
 class KRDPServerConfig : public KQuickManagedConfigModule
 {
@@ -18,6 +20,9 @@ public:
     ~KRDPServerConfig() override;
 
     Q_PROPERTY(QString hostName READ hostName CONSTANT)
+    Q_PROPERTY(bool managementAvailable READ managementAvailable CONSTANT)
+
+    Q_PROPERTY(QAbstractItemModel *users READ usersModel CONSTANT)
 
     Q_INVOKABLE QString toLocalFile(const QUrl &url);
 
@@ -45,6 +50,11 @@ public:
     };
 
     QString hostName() const;
+    bool managementAvailable() const;
+    QAbstractItemModel *usersModel() const
+    {
+        return m_usersModel;
+    };
 
 public Q_SLOTS:
     void save() override;
@@ -61,6 +71,7 @@ Q_SIGNALS:
 private:
     void createRestoreToken();
     KRDPServerSettings *m_serverSettings;
+    UsersModel *m_usersModel;
     Q_SLOT void servicePropertiesChanged();
     bool m_isH264Supported { false };
 };
